/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.dhcp.soap
 * File:    LeaseMessageBuilder.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.dhcp.soap;

import java.util.ArrayList;
import java.util.Calendar;

import de.fhhannover.inform.iron.dhcp.parser.Lease;

/**
 * This Class converts Lease Objects into LeaseMessage Objects
 *
 * @version 	0.01 24 Nov 2009
 * @version 	0.02 15 Dez 2009
 * @version	    0.03 11 May 2010
 * @author 	Sebastian Kobert
 */
public class LeaseMessageBuilder {
	
	/**
	 * This Method converts the given ArrayList with Lease Objects into an ArrayList with LeaseMessage Objects. 
	 * 
	 * @param leases a ArrayList that contains all Lease Objects that need to be converted to LeaseMessage Objects.
	 * @return a ArrayList that contains all LeaseMessages that need to be send. 
	 */
	public static ArrayList<LeaseMessage> createLeaseMessages (ArrayList<Lease> leases, int messageType){
		//the List that should be returned
	    ArrayList<LeaseMessage> returnList = new ArrayList<LeaseMessage>(leases.size());
	    
		for(int i = 0; i < leases.size(); i++){
			// get the Lease Object
			Lease tmpLease = leases.get(i);
			
			// get the attributes of the Lease Object
			String ip = tmpLease.getIp();
			String mac = tmpLease.getMac();
			Calendar start = tmpLease.getStart();
			Calendar end = tmpLease.getEnd();
			
			LeaseMessage tmpLeaseMessage = new LeaseMessage(messageType, ip, mac, start, end);
			
			returnList.add(tmpLeaseMessage);			
		}
		
		return returnList;		
	}

}
