/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.dhcp.soap
 * File:    SOAPControl.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.dhcp.soap;

import java.rmi.RemoteException;
import java.util.ArrayList;

import de.fhhannover.inform.iron.dhcp.control.Config;
import de.fhhannover.inform.iron.dhcp.parser.Lease;

/**
 * This Class controls how the Messages should be send to the IF-MAP Server 
 * 
 * @version 	0.01 15 Dez 2009
 * @version 	0.02 21 Dez 2009
 * @version		0.03 17 Mar 2010
 * @version		0.04 13 Apr 2010
 * @version	    0.05 11 May 2010
 * @author 	Sebastian Kobert
 */
public class SOAPControl {
	
	/**
	 * This Method controls how the Messages should be send to the IF-MAP Server 
	 * 
	 * @param leases This ArrayList contains all Lease Objects that should be send 		
	 */
	public static void sendSOAPMessages(ArrayList<Lease> leases){
		
		if(leases != null){
			
			if(leases.size() != 0){
				
				ArrayList<LeaseMessage> leaseMessages = new ArrayList<LeaseMessage>(leases.size());
				
				leaseMessages = LeaseMessageBuilder.createLeaseMessages(leases, LeaseMessage.UPDATE_MESSAGE);
				
				SOAPMessageSender.getInstance().sendMessages(leaseMessages);
				if(Config.MAPDHCP_RENEWSESSION_ENABLED)
					SOAPMessageSender.getInstance().activateReNewSession(true);
			}
		}
		
	}
	
	/**
	 * This Method controls how the Messages should be deleted from the IF-MAP Server 
	 * 
	 * @param leases This ArrayList contains all Lease Objects that should be deleted 		
	 */
	public static void deleteSOAPMessages(ArrayList<Lease> leases){
		
		if(leases != null){
			
			if(leases.size() != 0){
				
				ArrayList<LeaseMessage> leaseMessages = new ArrayList<LeaseMessage>(leases.size());
				
				leaseMessages = LeaseMessageBuilder.createLeaseMessages(leases, LeaseMessage.DELETE_MESSAGE);
				
				SOAPMessageSender.getInstance().sendMessages(leaseMessages);
			}
		}
		
	}
	
	/**
	 * Purges the published Metadata on MAPS
	 * @return true if action is succesfull, false otherwise
	 */
	public static boolean sendPurgePublisher(){
		return SOAPMessageSender.getInstance().makeAPurgePublish();
	}
	
	/**
	 * Sends an endSession() to the MAPS
	 * @throws RemoteException
	 */
	public static void endSession() throws RemoteException{
		SOAPMessageSender.getInstance().redirectEndSession();
	}

}
