/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.dhcp.soap
 * File:    SecureIFMap.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.dhcp.soap;

import org.apache.axis2.AxisFault;
import org.apache.axis2.client.Options;
import org.apache.axis2.context.ConfigurationContextFactory;
import org.apache.axis2.transport.http.HttpTransportProperties;
import org.trustedcomputinggroup.www._2010.ifmap._2.ifmap_wsdl.IfmapServiceStub;

import de.fhhannover.inform.iron.dhcp.control.Config;

/*
 * Author Waldemar Bender
 * SecureIFMap
 * 
 * 
 */

public class SecureIFMap extends IfmapServiceStub {
	
	public SecureIFMap(String axis2XMLURL, String webServiceURL, String trustStoreURL, String keyStoreURL) throws AxisFault  {
		super(ConfigurationContextFactory.createConfigurationContextFromFileSystem(axis2XMLURL), webServiceURL);	
		setProps(trustStoreURL, keyStoreURL);
	}
	
	public SecureIFMap(String webServiceURL, String trustStoreURL, String keyStoreURL) throws AxisFault  {
		super(webServiceURL);
		setProps(trustStoreURL, keyStoreURL);
	}
	
	public SecureIFMap(String axis2XMLURL, String webServiceURL, String trustStoreURL, String keyStoreURL, boolean useSeperateListener) throws AxisFault  {
		super(ConfigurationContextFactory.createConfigurationContextFromFileSystem(axis2XMLURL), webServiceURL, useSeperateListener);
		setProps(trustStoreURL, keyStoreURL);
	}
	

	/**
	 * Sets the properties for SSL-Authentication
	 */
	public void setProps(String trustStoreURL, String keyStoreURL)	{
		Options options = this._getServiceClient().getOptions();
	if(Config.MAPSERVER_BASICAUTH_ENABLED){				
		HttpTransportProperties.Authenticator auth = new HttpTransportProperties.Authenticator();		
		auth.setUsername(Config.MAPSERVER_BASICAUTH_USER);
		auth.setPassword(Config.MAPSERVER_BASICAUTH_PASSWORD);		
		options.setProperty(org.apache.axis2.transport.http.HTTPConstants.AUTHENTICATE, auth);	
		auth.setPreemptiveAuthentication(true);
	}
			String keystorepw = Config.MAPSERVER_KEYSTORE_PASSWORD; 
			String truststorepw = Config.MAPSERVER_TRUSTSTORE_PASSWORD;
			System.setProperty("javax.net.ssl.trustStore", trustStoreURL);
			System.setProperty("javax.net.ssl.trustStorePassword",truststorepw); 
			System.setProperty("javax.net.ssl.keyStore", keyStoreURL);
			System.setProperty("javax.net.ssl.keyStorePassword",keystorepw);
			options.setProperty(org.apache.axis2.transport.http.HTTPConstants.CHUNKED, Boolean.FALSE);
			options.setProperty(org.apache.axis2.transport.http.HTTPConstants.REUSE_HTTP_CLIENT, Boolean.TRUE);			
			options
					.setProperty(
							org.apache.axis2.transport.http.HTTPConstants.CONNECTION_TIMEOUT,
							0);
			options.setProperty(
					org.apache.axis2.transport.http.HTTPConstants.SO_TIMEOUT, 0);
			options.setTimeOutInMilliSeconds(0);
			options.setSoapVersionURI(org.apache.axiom.soap.SOAP12Constants.SOAP_ENVELOPE_NAMESPACE_URI);
			options.setProperty(org.apache.axis2.transport.http.HTTPConstants.CONTENT_TYPE, "application/soap+xml");
	}
}
